@@ -4,18 +4,18 @@
 :copyright: (c) 2022 Superior_6564
 """
 
-
 import subprocess
 import sys
 import os
 
 
-def install(package):
+def install(package: str, check=True):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
     subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", package])
-    if os.getcwd() == "/content":
-        package = "pip show " + package
-        get_ipython().system(package)
+    if check:
+        if os.getcwd() == "/content":
+            package = "pip show " + package
+            get_ipython().system(package)
 
 
 def pip_upgrade():
@@ -24,5 +24,6 @@ def pip_upgrade():
 
 def required():
     print("Установка необходимых библиотек")
-    install("requests")
+    install("requests", check=False)
+    install("opencv-python", check=False)
     print("Установка завершена")
